# edfrw

**edfrw** is a Python library for reading and writing European Data
Format (EDF) files.

EDF is a format for data storage that is particularly useful for
recording biological and physical signals. The format is described in
detail on the [EDF website](http://www.edfplus.info).

## Requirements

* [Python 3](https://www.python.org/) (>= 3.5)
* A recent version of [NumPy](https://numpy.org/)

In addition, if you want to try the examples, you may want to install
[Matplotlib](https://matplotlib.org/) for plotting the data.

## Installation

**edfrw** is available on [PyPI](https://pypi.org/). Thus, the easiest
way to install is with `pip`:

    python -m pip install edfrw

Alternatively, you can download the code from
[GitHub](https://github.com/antgon/edfrw) and place it somewhere on your
Python path, or install locally with `pip`.

## Links

* The documentation is available [here](https://antgon.github.io/edfrw/).
* The [source code](https://github.com/antgon/edfrw) is on GitHub.
* The code is licensed under the [GNU General Public License](http://www.gnu.org/licenses/gpl.html).